@@ -23,7 +23,7 @@
 // You can contact University Corporation for Atmospheric Research at
 // 3080 Center Green Drive, Boulder, CO 80301
  
-// (c) COPYRIGHT University Corporation for Atmostpheric Research 2004-2005
+// (c) COPYRIGHT University Corporation for Atmospheric Research 2004-2005
 // Please read the full copyright statement in the file COPYRIGHT_UCAR.
 //
 // Authors:
@@ -34,38 +34,43 @@
 using std::endl ;
 
 #include "FFModule.h"
-#include "BESRequestHandlerList.h"
+#include <BESRequestHandlerList.h>
 #include "FFRequestHandler.h"
-#include "BESContainerStorageList.h"
-#include "BESContainerStorageCatalog.h"
-#include "BESCatalogDirectory.h"
-#include "BESCatalogList.h"
-#include "BESDebug.h"
+#include <BESDapService.h>
+#include <BESContainerStorageList.h>
+#include <BESContainerStorageCatalog.h>
+#include <BESCatalogDirectory.h>
+#include <BESCatalogList.h>
+#include <BESDebug.h>
 
 #define FF_CATALOG "catalog"
 
 void
 FFModule::initialize( const string &modname )
 {
-    BESDEBUG( "ff", "Initializing FF module " << modname << endl )
+    BESDEBUG( "ff", "Initializing FF module " << modname << endl ) ;
 
-    BESDEBUG( "ff", "    adding " << modname << " request handler" << endl )
+    BESDEBUG( "ff", "    adding " << modname << " request handler" << endl ) ;
     BESRequestHandler *handler = new FFRequestHandler( modname ) ;
     BESRequestHandlerList::TheList()->add_handler( modname, handler ) ;
 
-    BESDEBUG( "ff", "    adding " << FF_CATALOG << " catalog" << endl )
-    if( !BESCatalogList::TheCatalogList()->find_catalog( FF_CATALOG ) )
+    BESDEBUG( "ff", modname << " handles dap services" << endl ) ;
+    BESDapService::handle_dap_service( modname ) ;
+
+    BESDEBUG( "ff", "    adding " << FF_CATALOG << " catalog" << endl ) ;
+    if( !BESCatalogList::TheCatalogList()->ref_catalog( FF_CATALOG ) )
     {
 	BESCatalogList::TheCatalogList()->
 	    add_catalog( new BESCatalogDirectory( FF_CATALOG ) ) ;
     }
     else
     {
-	BESDEBUG( "ff", "    catalog already exists, skipping" << endl )
+	BESDEBUG( "ff", "    catalog already exists, skipping" << endl ) ;
     }
 
-    BESDEBUG( "ff", "    adding catalog container storage" << FF_CATALOG << endl )
-    if( !BESContainerStorageList::TheList()->find_persistence( FF_CATALOG ) )
+    BESDEBUG( "ff", "    adding catalog container storage"
+		    << FF_CATALOG << endl ) ;
+    if( !BESContainerStorageList::TheList()->ref_persistence( FF_CATALOG ) )
     {
 	BESContainerStorageCatalog *csc =
 	    new BESContainerStorageCatalog( FF_CATALOG ) ;
@@ -73,31 +78,32 @@ FFModule::initialize( const string &modname )
     }
     else
     {
-	BESDEBUG( "ff", "    storage already exists, skipping" << endl )
+	BESDEBUG( "ff", "    storage already exists, skipping" << endl ) ;
     }
 
-    BESDEBUG( "ff", "    adding ff debug context" << endl )
+    BESDEBUG( "ff", "    adding ff debug context" << endl ) ;
     BESDebug::Register( "ff" ) ;
 
-    BESDEBUG( "ff", "Done Initializing FF module " << modname << endl )
+    BESDEBUG( "ff", "Done Initializing FF module " << modname << endl ) ;
 }
 
 void
 FFModule::terminate( const string &modname )
 {
-    BESDEBUG( "ff", "Cleaning FF module " << modname << endl )
+    BESDEBUG( "ff", "Cleaning FF module " << modname << endl ) ;
 
-    BESDEBUG( "ff", "    removing FF Handler" << modname << endl )
+    BESDEBUG( "ff", "    removing FF Handler" << modname << endl ) ;
     BESRequestHandler *rh = BESRequestHandlerList::TheList()->remove_handler( modname ) ;
     if( rh ) delete rh ;
 
-    BESDEBUG( "ff", "    removing catalog container storage" << FF_CATALOG << endl )
-    BESContainerStorageList::TheList()->del_persistence( FF_CATALOG ) ;
+    BESDEBUG( "ff", "    removing catalog container storage"
+		    << FF_CATALOG << endl ) ;
+    BESContainerStorageList::TheList()->deref_persistence( FF_CATALOG ) ;
 
-    BESDEBUG( "ff", "    removing " << FF_CATALOG << " catalog" << endl )
-    BESCatalogList::TheCatalogList()->del_catalog( FF_CATALOG ) ;
+    BESDEBUG( "ff", "    removing " << FF_CATALOG << " catalog" << endl) ;
+    BESCatalogList::TheCatalogList()->deref_catalog( FF_CATALOG ) ;
 
-    BESDEBUG( "ff", "Done Cleaning FF module " << modname << endl )
+    BESDEBUG( "ff", "Done Cleaning FF module " << modname << endl ) ;
 }
 
 /** @brief dumps information about this object
