@@ -25,36 +25,34 @@
 
 // FFRequestHandler.cc
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <unistd.h>
-
 #include "FFRequestHandler.h"
 
 #include "config_ff.h"
-#include "FFTypeFactory.h"
 #include "ff_ce_functions.h"
+#include "util_ff.h"
 
-#include "BESDASResponse.h"
-#include "BESDDSResponse.h"
-#include "BESDataDDSResponse.h"
-#include "BESInfo.h"
-#include "BESResponseNames.h"
-#include "BESContainer.h"
-#include "BESResponseHandler.h"
-#include "BESVersionInfo.h"
-#include "BESDataNames.h"
+#include <BESDASResponse.h>
+#include <BESDDSResponse.h>
+#include <BESDataDDSResponse.h>
+#include <BESInfo.h>
+#include <BESDapNames.h>
+#include <BESResponseNames.h>
+#include <BESContainer.h>
+#include <BESResponseHandler.h>
+#include <BESVersionInfo.h>
+#include <BESServiceRegistry.h>
+#include <BESUtil.h>
 
-#include "BESDapError.h"
-#include "BESInternalFatalError.h"
-#include "InternalErr.h"
+#include <BESDapError.h>
+#include <BESInternalFatalError.h>
+#include <InternalErr.h>
 
 #include <DDS.h>
 #include <Ancillary.h>
 #include <Error.h>
 #include <escaping.h>
-#include <cgi_util.h>
+
+#define FF_NAME "ff"
 
 long BufPtr = 0;                // cache pointer
 long BufSiz = 0;                // Cache size
@@ -79,15 +77,26 @@ FFRequestHandler::~FFRequestHandler()
 
 bool FFRequestHandler::ff_build_das(BESDataHandlerInterface & dhi)
 {
-    BESDASResponse *bdas =
-        dynamic_cast <
-        BESDASResponse * >(dhi.response_handler->get_response_object());
-    DAS *das = bdas->get_das();
+    BESResponseObject *response = dhi.response_handler->get_response_object() ;
+    BESDASResponse *bdas = dynamic_cast < BESDASResponse * >(response) ;
+    if( !bdas )
+	throw BESInternalError( "cast error", __FILE__, __LINE__ ) ;
 
     try {
+	bdas->set_container( dhi.container->get_symbolic_name() ) ;
+	DAS *das = bdas->get_das();
+
 	string accessed = dhi.container->access() ;
         ff_get_attributes(*das, accessed);
-	Ancillary::read_ancillary_das( *das, accessed ) ;
+#ifdef RSS
+	string name = find_ancillary_rss_das(accessed);
+#else
+        string name = Ancillary::find_ancillary_file(accessed, "das", "", "");
+#endif
+        if (!name.empty())
+            das->parse(name);
+
+	bdas->clear_container() ;
     }
     catch(InternalErr & e) {
         BESDapError ex( e.get_error_message(), true, e.get_error_code(),
@@ -110,34 +119,32 @@ bool FFRequestHandler::ff_build_das(BESDataHandlerInterface & dhi)
 
 bool FFRequestHandler::ff_build_dds(BESDataHandlerInterface & dhi)
 {
-    BESDDSResponse *bdds =
-        dynamic_cast <
-        BESDDSResponse * >(dhi.response_handler->get_response_object());
-    DDS *dds = bdds->get_dds();
-    ConstraintEvaluator & ce = bdds->get_ce();
-
+    BESResponseObject *response = dhi.response_handler->get_response_object();
+    BESDDSResponse *bdds = dynamic_cast < BESDDSResponse * >(response);
+    if( !bdds )
+	throw BESInternalError( "cast error", __FILE__, __LINE__ ) ;
+  
     try {
-        FFTypeFactory *factory = new FFTypeFactory;
-        dds->set_factory(factory);
+	bdds->set_container( dhi.container->get_symbolic_name() ) ;
+	DDS *dds = bdds->get_dds();
+	ConstraintEvaluator & ce = bdds->get_ce();
 
         ff_register_functions(ce);
 	string accessed = dhi.container->access();
         dds->filename(accessed);
         ff_read_descriptors(*dds, accessed);
-	Ancillary::read_ancillary_dds( *dds, accessed ) ;
 
-        DAS das;
-        ff_get_attributes(das, accessed);
-	Ancillary::read_ancillary_das( das, accessed ) ;
+        DAS *das = new DAS ;
+	BESDASResponse bdas( das ) ;
+	bdas.set_container( dhi.container->get_symbolic_name() ) ;
+        ff_get_attributes( *das, accessed ) ;
+	Ancillary::read_ancillary_das( *das, accessed ) ;
         
-        dds->transfer_attributes(&das);
+        dds->transfer_attributes( das ) ;
 
-        dhi.data[POST_CONSTRAINT] = dhi.container->get_constraint();
-#if 0
-        // see ticket 720
-        dds->set_factory(NULL);
-        delete factory;
-#endif
+	bdds->set_constraint( dhi ) ;
+
+	bdds->clear_container() ;
     }
     catch(InternalErr & e) {
         BESDapError ex( e.get_error_message(), true, e.get_error_code(),
@@ -164,35 +171,33 @@ bool FFRequestHandler::ff_build_data(BESDataHandlerInterface & dhi)
     BufSiz = 0;                 // Cache size
     BufVal = NULL;              // cache buffer
 
-    BESDataDDSResponse *bdds =
-        dynamic_cast <BESDataDDSResponse *>(dhi.response_handler->get_response_object());
-    DataDDS *dds = bdds->get_dds();
-    ConstraintEvaluator & ce = bdds->get_ce();
-
+    BESResponseObject *response = dhi.response_handler->get_response_object();
+    BESDataDDSResponse *bdds = dynamic_cast < BESDataDDSResponse * >(response);
+    if( !bdds )
+	throw BESInternalError( "cast error", __FILE__, __LINE__ ) ;
+  
     try {
-        FFTypeFactory *factory = new FFTypeFactory;
-        dds->set_factory(factory);
-        
+	bdds->set_container( dhi.container->get_symbolic_name() ) ;
+	DataDDS *dds = bdds->get_dds();
+	ConstraintEvaluator & ce = bdds->get_ce();
+
         ff_register_functions(ce);
         string accessed = dhi.container->access();
         dds->filename(accessed);
         ff_read_descriptors(*dds, accessed);
 	Ancillary::read_ancillary_dds( *dds, accessed ) ;
 
-        DAS das;
-        ff_get_attributes(das, accessed);
-	Ancillary::read_ancillary_das( das, accessed ) ;
+        DAS *das = new DAS ;
+	BESDASResponse bdas( das ) ;
+	bdas.set_container( dhi.container->get_symbolic_name() ) ;
+        ff_get_attributes( *das, accessed ) ;
+	Ancillary::read_ancillary_das( *das, accessed ) ;
         
-        dds->transfer_attributes(&das);
-#if 0        
-        dhi.data[POST_CONSTRAINT] = www2id(dhi.container->get_constraint(), "%", "%20");
-#endif
-        dhi.data[POST_CONSTRAINT] = dhi.container->get_constraint();
-#if 0
-        // see ticket 720
-        dds->set_factory(NULL);
-        delete factory;
-#endif
+        dds->transfer_attributes( das ) ;
+
+	bdds->set_constraint( dhi ) ;
+
+	bdds->clear_container() ;
     }
     catch(InternalErr & e) {
         BESDapError ex( e.get_error_message(), true, e.get_error_code(),
@@ -215,23 +220,35 @@ bool FFRequestHandler::ff_build_data(BESDataHandlerInterface & dhi)
 
 bool FFRequestHandler::ff_build_help(BESDataHandlerInterface & dhi)
 {
-    BESInfo *info =
-        (BESInfo *) dhi.response_handler->get_response_object();
-    info->begin_tag("Handler");
-    info->add_tag("name", PACKAGE_NAME);
-    string handles = (string) DAS_RESPONSE + "," + DDS_RESPONSE
-        + "," + DATA_RESPONSE + "," + HELP_RESPONSE + "," + VERS_RESPONSE;
-    info->add_tag("handles", handles);
-    info->add_tag("version", PACKAGE_STRING);
-    info->end_tag("Handler");
+    BESResponseObject *response = dhi.response_handler->get_response_object();
+    BESInfo *info = dynamic_cast<BESInfo *>(response);
+    if( !info )
+	throw BESInternalError( "cast error", __FILE__, __LINE__ ) ;
+
+    map<string,string> attrs ;
+    attrs["name"] = PACKAGE_NAME ;
+    attrs["version"] = PACKAGE_VERSION ;
+    list<string> services ;
+    BESServiceRegistry::TheRegistry()->services_handled( FF_NAME, services );
+    if( services.size() > 0 )
+    {
+	string handles = BESUtil::implode( services, ',' ) ;
+	attrs["handles"] = handles ;
+    }
+    info->begin_tag( "module", &attrs ) ;
+    info->end_tag( "module" ) ;
 
     return true;
 }
 
 bool FFRequestHandler::ff_build_version(BESDataHandlerInterface & dhi)
 {
-    BESVersionInfo *info =
-        (BESVersionInfo *) dhi.response_handler->get_response_object();
-    info->addHandlerVersion(PACKAGE_NAME, PACKAGE_VERSION);
-    return true;
+    BESResponseObject *response = dhi.response_handler->get_response_object();
+    BESVersionInfo *info = dynamic_cast < BESVersionInfo * >(response);
+    if( !info )
+	throw BESInternalError( "cast error", __FILE__, __LINE__ ) ;
+  
+    info->add_module( PACKAGE_NAME, PACKAGE_VERSION ) ;
+
+    return true ;
 }
