@@ -11,12 +11,12 @@
 // terms of the GNU Lesser General Public License as published by the Free
 // Software Foundation; either version 2.1 of the License, or (at your
 // option) any later version.
-// 
+//
 // This software is distributed in the hope that it will be useful, but
 // WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 // or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 // License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -30,7 +30,7 @@
 //      jhrg,jimg       James Gallagher (jgallagher@gso.uri.edu)
 
 // This file contains various functions for use with/in constraint
-// expressions. 
+// expressions.
 
 #include <iostream>
 #include <string>
@@ -44,7 +44,6 @@
 #include "ConstraintEvaluator.h"
 #include "Error.h"
 #include "util.h"
-#include "cgi_util.h"
 #include "debug.h"
 
 #include "date_proc.h"
@@ -62,30 +61,16 @@
 #include "DODS_EndDate_Time_Factory.h"
 
 #include "ff_ce_functions.h"
+#include "FFStr.h"
 
 /** Read an instance of T using a Factory for objects of type T. The Factory
     class for T must read configuration information from the DAS.
 
     @return An instance of the class T. */
 
-template < class T, class T_Factory > 
+template < class T, class T_Factory >
 inline static T get_instance(DDS & dds)
 {
-#if 0
-    // This code break when used with the BES.
-    static T_Factory *tf = 0;
-    if (!tf) {
-        // Hack
-        string name = find_ancillary_file(dds.filename(), "das", "", "");
-        DAS das;
-        das.parse(name);
-        // end hack
-        tf = new T_Factory(dds, das);
-    }
-
-    return tf->get();
-#endif
-
     return T_Factory(dds).get();
 }
 
@@ -115,19 +100,10 @@ template < class T, class T_Factory >
         t2.set(argv[1]);
 
     T current = get_instance < T, T_Factory > (dds);
-    bool te;
-
-    if (argc == 2) {
-#if 0
-        te = ((t1 <= current) && (t2 >= current));
-#endif
+    if (argc == 2)
         return ((t1 <= current) && (t2 >= current));
-    } else {
-#if 0
-        te = (t1 == current);
-#endif
+    else
         return (t1 == current);
-    }
 }
 
 /** Compare an instance of T read from the dataset with the strings in one or
@@ -170,12 +146,11 @@ template < class T1, class T1_Factory, class T2, class T2_Factory >
     @param position Add the new variable to this Structure or Sequence. */
 
 static void
-new_string_variable(const string & name, DDS & dds, BaseType * position =
-                    0)
+new_string_variable(const string & name, DDS & dds, BaseType * position = 0)
 {
     // Create the new variable
 
-    Str *new_variable = dds.get_factory()->NewStr(name.c_str());
+    Str *new_variable = new FFStr(name, "");
     new_variable->set_read_p(true);     // You must call this before ...
     new_variable->set_synthesized_p(true);      // this! Look at BaseType.cc.
 
@@ -196,90 +171,94 @@ new_string_variable(const string & name, DDS & dds, BaseType * position =
             }
 
         default:
+            delete new_variable;
             throw Error(malformed_expr,
                         "You asked me to insert the synthesized variable in \n\
 something that did not exist or was not a constructor \n\
 type (e.g., a structure, sequence, ...).");
             break;
         }
-    } else {
+    } 
+    else {
         dds.add_var(new_variable);
     }
 
     // Mark the variable as part of the current projection.
 
     dds.mark(name, true);       // Don't just call set_send_p()!
+    
+    delete new_variable;
 }
 
-static bool func_date(int argc, BaseType * argv[], DDS & dds)
+static void func_date(int argc, BaseType * argv[], DDS & dds, bool *result)
 {
-    return comparison < DODS_Date, DODS_Date_Factory > (argc, argv, dds);
+    *result = comparison < DODS_Date, DODS_Date_Factory > (argc, argv, dds);
 }
 
-static bool func_startdate(int argc, BaseType * argv[], DDS & dds)
+static void func_startdate(int argc, BaseType * argv[], DDS & dds, bool *result)
 {
-    return comparison < DODS_Date, DODS_StartDate_Factory > (argc, argv,
+    *result = comparison < DODS_Date, DODS_StartDate_Factory > (argc, argv,
                                                              dds);
 }
 
-static bool func_enddate(int argc, BaseType * argv[], DDS & dds)
+static void func_enddate(int argc, BaseType * argv[], DDS & dds, bool *result)
 {
-    return comparison < DODS_Date, DODS_EndDate_Factory > (argc, argv,
+    *result = comparison < DODS_Date, DODS_EndDate_Factory > (argc, argv,
                                                            dds);
 }
 
-static bool func_date_range(int argc, BaseType * argv[], DDS & dds)
+static void func_date_range(int argc, BaseType * argv[], DDS & dds, bool *result)
 {
-    return range_comparison < DODS_Date, DODS_StartDate_Factory, DODS_Date,
+    *result = range_comparison < DODS_Date, DODS_StartDate_Factory, DODS_Date,
         DODS_EndDate_Factory > (argc, argv, dds);
 }
 
-static bool func_time(int argc, BaseType * argv[], DDS & dds)
+static void func_time(int argc, BaseType * argv[], DDS & dds, bool *result)
 {
-    return comparison < DODS_Time, DODS_Time_Factory > (argc, argv, dds);
+    *result = comparison < DODS_Time, DODS_Time_Factory > (argc, argv, dds);
 }
 
-static bool func_starttime(int argc, BaseType * argv[], DDS & dds)
+static void func_starttime(int argc, BaseType * argv[], DDS & dds, bool *result)
 {
-    return comparison < DODS_Time, DODS_StartTime_Factory > (argc, argv,
+    *result = comparison < DODS_Time, DODS_StartTime_Factory > (argc, argv,
                                                              dds);
 }
 
-static bool func_endtime(int argc, BaseType * argv[], DDS & dds)
+static void func_endtime(int argc, BaseType * argv[], DDS & dds, bool *result)
 {
-    return comparison < DODS_Time, DODS_EndTime_Factory > (argc, argv,
+    *result = comparison < DODS_Time, DODS_EndTime_Factory > (argc, argv,
                                                            dds);
 }
 
 // This comparision function should be used for decimal dates. 5/29/99 jhrg
 
-static bool func_date_time(int argc, BaseType * argv[], DDS & dds)
+static void func_date_time(int argc, BaseType * argv[], DDS & dds, bool *result)
 {
-    return comparison < DODS_Date_Time, DODS_Date_Time_Factory > (argc,
+    *result = comparison < DODS_Date_Time, DODS_Date_Time_Factory > (argc,
                                                                   argv,
                                                                   dds);
 }
 
-static bool func_startdate_time(int argc, BaseType * argv[], DDS & dds)
+static void func_startdate_time(int argc, BaseType * argv[], DDS & dds, bool *result)
 {
-    return comparison < DODS_Date_Time,
+    *result = comparison < DODS_Date_Time,
         DODS_StartDate_Time_Factory > (argc, argv, dds);
 }
 
-static bool func_enddate_time(int argc, BaseType * argv[], DDS & dds)
+static void func_enddate_time(int argc, BaseType * argv[], DDS & dds, bool *result)
 {
-    return comparison < DODS_Date_Time, DODS_EndDate_Time_Factory > (argc,
+    *result = comparison < DODS_Date_Time, DODS_EndDate_Time_Factory > (argc,
                                                                      argv,
                                                                      dds);
 }
 
 // This function is added to the selection part of the CE when the matching
-// `projection function' is run. 
+// `projection function' is run.
 
 // The date and date_time functions should now recognize decimal format years
 // and date-times. 5/30/99 jhrg
 
-static bool sel_dods_jdate(int argc, BaseType *[], DDS & dds)
+static void sel_dods_jdate(int argc, BaseType *[], DDS & dds, bool *result)
 {
     if (argc != 0)
         throw Error(malformed_expr,
@@ -296,7 +275,7 @@ Please report this error.");
     string s = current.get(yd).c_str();
     dods_jdate->val2buf(&s);
 
-    return true;
+    *result = true;
 }
 
 // A projection function: This adds a new variable to the DDS and arranges
@@ -320,7 +299,7 @@ Expected zero or one arguments.");
 
 // Same as the above function, but for ymd dates.
 
-static bool sel_dods_date(int argc, BaseType *[], DDS & dds)
+static void sel_dods_date(int argc, BaseType *[], DDS & dds, bool *result)
 {
     if (argc != 0)
         throw Error(malformed_expr,
@@ -337,7 +316,7 @@ Please report this error.");
     string s = current.get().c_str();
     dods_date->val2buf(&s);
 
-    return true;
+    *result = true;
 }
 
 static void
@@ -359,7 +338,7 @@ Expected zero or one arguments.");
 /************************ DODS_Time functions *************************/
 
 
-static bool sel_dods_time(int argc, BaseType *[], DDS & dds)
+static void sel_dods_time(int argc, BaseType *[], DDS & dds, bool *result)
 {
     if (argc != 0)
         throw Error(malformed_expr,
@@ -374,7 +353,7 @@ Please report this error.");
     string s = current.get().c_str();
     dods_time->val2buf(&s);
 
-    return true;
+    *result = true;
 }
 
 static void
@@ -398,9 +377,9 @@ Expected zero or one arguments.");
 /*************************** Date/Time functions *************************/
 
 // This function is added to the selection part of the CE when the matching
-// `projection function' is run. 
+// `projection function' is run.
 
-static bool sel_dods_date_time(int argc, BaseType *[], DDS & dds)
+static void sel_dods_date_time(int argc, BaseType *[], DDS & dds, bool *result)
 {
     if (argc != 0)
         throw Error(malformed_expr,
@@ -414,7 +393,7 @@ Please report this error.");
     string s = current.get().c_str();
     dods_date_time->val2buf(&s);
 
-    return true;
+    *result = true;
 }
 
 // A projection function: This adds a new variable to the DDS and arranges
@@ -441,9 +420,9 @@ Expected zero or one arguments.");
 /*************************** Decimal/Year functions *************************/
 
 // This function is added to the selection part of the CE when the matching
-// `projection function' is run. 
+// `projection function' is run.
 
-static bool sel_dods_decimal_year(int argc, BaseType *[], DDS & dds)
+static void sel_dods_decimal_year(int argc, BaseType *[], DDS & dds, bool *result)
 {
     if (argc != 0)
         throw Error(malformed_expr,
@@ -458,7 +437,7 @@ Please report this error.");
     string s = current.get(decimal);
     dods_decimal_year->val2buf(&s);
 
-    return true;
+    *result = true;
 }
 
 // A projection function: This adds a new variable to the DDS and arranges
@@ -486,9 +465,9 @@ Expected zero or one arguments.");
 /*************************** Decimal/Year functions *************************/
 
 // This function is added to the selection part of the CE when the matching
-// `projection function' is run. 
+// `projection function' is run.
 
-static bool sel_dods_startdecimal_year(int argc, BaseType *[], DDS & dds)
+static void sel_dods_startdecimal_year(int argc, BaseType *[], DDS & dds, bool *result)
 {
     if (argc != 0)
         throw Error(malformed_expr,
@@ -504,7 +483,7 @@ Please report this error.");
     string s = current.get(decimal);
     dods_decimal_year->val2buf(&s);
 
-    return true;
+    *result = true;
 }
 
 // A projection function: This adds a new variable to the DDS and arranges
@@ -532,9 +511,9 @@ Expected zero or one arguments.");
 /*************************** Decimal/Year functions *************************/
 
 // This function is added to the selection part of the CE when the matching
-// `projection function' is run. 
+// `projection function' is run.
 
-static bool sel_dods_enddecimal_year(int argc, BaseType *[], DDS & dds)
+static void sel_dods_enddecimal_year(int argc, BaseType *[], DDS & dds, bool *result)
 {
     if (argc != 0)
         throw Error(malformed_expr,
@@ -549,7 +528,7 @@ Please report this error.");
     string s = current.get(decimal);
     dods_decimal_year->val2buf(&s);
 
-    return true;
+    *result = true;
 }
 
 // A projection function: This adds a new variable to the DDS and arranges
@@ -576,7 +555,7 @@ Expected zero or one arguments.");
 
 /************************ DODS_StartDate functions *************************/
 
-static bool sel_dods_startdate(int argc, BaseType *[], DDS & dds)
+static void sel_dods_startdate(int argc, BaseType *[], DDS & dds, bool *result)
 {
     if (argc != 0)
         throw Error(malformed_expr,
@@ -593,7 +572,7 @@ Please report this error.");
     string s = current.get().c_str();
     dods_date->val2buf(&s);
 
-    return true;
+    *result = true;
 }
 
 static void
@@ -614,7 +593,7 @@ Expected zero or one arguments.");
 
 /************************ DODS_StartTime functions *************************/
 
-static bool sel_dods_starttime(int argc, BaseType *[], DDS & dds)
+static void sel_dods_starttime(int argc, BaseType *[], DDS & dds, bool *result)
 {
     if (argc != 0)
         throw Error(malformed_expr,
@@ -629,7 +608,7 @@ Please report this error.");
     string s = current.get().c_str();
     dods_time->val2buf(&s);
 
-    return true;
+    *result = true;
 }
 
 static void
@@ -653,9 +632,9 @@ Expected zero or one arguments.");
 /*************************** StartDate/Time functions *************************/
 
 // This function is added to the selection part of the CE when the matching
-// `projection function' is run. 
+// `projection function' is run.
 
-static bool sel_dods_startdate_time(int argc, BaseType *[], DDS & dds)
+static void sel_dods_startdate_time(int argc, BaseType *[], DDS & dds, bool *result)
 {
     if (argc != 0)
         throw Error(malformed_expr,
@@ -670,7 +649,7 @@ Please report this error.");
     string s = current.get().c_str();
     dods_date_time->val2buf(&s);
 
-    return true;
+    *result = true;
 }
 
 // A projection function: This adds a new variable to the DDS and arranges
@@ -697,7 +676,7 @@ Expected zero or one arguments.");
 
 /************************ DODS_EndDate functions *************************/
 
-static bool sel_dods_enddate(int argc, BaseType *[], DDS & dds)
+static void sel_dods_enddate(int argc, BaseType *[], DDS & dds, bool *result)
 {
     if (argc != 0)
         throw Error(malformed_expr,
@@ -714,7 +693,7 @@ Please report this error.");
     string s = current.get().c_str();
     dods_date->val2buf(&s);
 
-    return true;
+    *result = true;
 }
 
 static void
@@ -735,7 +714,7 @@ Expected zero or one arguments.");
 
 /************************ DODS_EndTime functions *************************/
 
-static bool sel_dods_endtime(int argc, BaseType *[], DDS & dds)
+static void sel_dods_endtime(int argc, BaseType *[], DDS & dds, bool *result)
 {
     if (argc != 0)
         throw Error(malformed_expr,
@@ -750,7 +729,7 @@ Please report this error.");
     string s = current.get().c_str();
     dods_time->val2buf(&s);
 
-    return true;
+    *result = true;
 }
 
 static void
@@ -774,9 +753,9 @@ Expected zero or one arguments.");
 /*************************** EndDate/Time functions *************************/
 
 // This function is added to the selection part of the CE when the matching
-// `projection function' is run. 
+// `projection function' is run.
 
-static bool sel_dods_enddate_time(int argc, BaseType *[], DDS & dds)
+static void sel_dods_enddate_time(int argc, BaseType *[], DDS & dds, bool *result)
 {
     if (argc != 0)
         throw Error(malformed_expr,
@@ -790,7 +769,7 @@ Please report this error.");
     string s = current.get().c_str();
     dods_date_time->val2buf(&s);
 
-    return true;
+    *result = true;
 }
 
 // A projection function: This adds a new variable to the DDS and arranges
