@@ -11,12 +11,12 @@
 // terms of the GNU Lesser General Public License as published by the Free
 // Software Foundation; either version 2.1 of the License, or (at your
 // option) any later version.
-// 
+//
 // This software is distributed in the hope that it will be useful, but
 // WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 // or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 // License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -35,10 +35,10 @@
 #include "config_ff.h"
 
 static char rcsid[] not_used =
-    { "$Id: util_ff.cc 17151 2007-09-20 23:17:58Z jimg $" };
+    { "$Id: util_ff.cc 19794 2008-11-03 17:27:46Z jimg $" };
 
 #ifndef WIN32
-#include <unistd.h>
+#include <unistd.h> // for access
 #else
 #define F_OK 0
 #endif
@@ -47,6 +47,7 @@ static char rcsid[] not_used =
 #include <sstream>
 #include <fstream>
 #include <string>
+#include <cstdlib>
 
 #include <BaseType.h>
 #include <InternalErr.h>
@@ -54,7 +55,7 @@ static char rcsid[] not_used =
 #include <debug.h>
 
 #include "util_ff.h"
-#include "FreeForm.h"
+// #include "FreeForm.h" Included by the util_ff header.
 
 using namespace std;
 
@@ -145,7 +146,7 @@ make_output_format(const string & name, Type type, const int width)
     return str.str();
 }
 
-// format for multi-dimension array 
+// format for multi-dimension array
 const string
 makeND_output_format(const string & name, Type type, const int width,
                      int ndim, const long *start, const long *edge, const
@@ -307,6 +308,114 @@ bool file_exist(const char *filename)
     return access(filename, F_OK) == 0;
 }
 
+/** Find the RSS (Remote Sensing Systems) format file using their naming
+    convention.
+
+    File naming convention: <data source> + '_' + <date_string> + <version> +
+    (optional)< _d3d > When <date_string> includes YYYYMMDDVV ('DD') the file
+    contains 'daily' data. When <date_string> only includes YYYYMMVV ( no
+    'DD'), or includes ('DD') and optional '_d3d' then the file contains
+    averaged data.
+
+    Different format files are required for 'daily' and 'averaged' data.
+
+    @return A const string object which contains the format file name. */
+const string
+find_ancillary_rss_formats(const string & dataset, const string & delimiter,
+			   const string & extension)
+{
+    string FormatFile;
+    //string FormatPath = getenv("FREEFORM_HANDLER_FORMATS");
+    string FormatPath = FREEFORM_HANDLER_FORMATS;
+    string BaseName;
+    string FileName;
+
+    size_t delim = dataset.rfind("#");
+    if ( delim != string::npos ) 
+      FileName = dataset.substr(delim+1,dataset.length()-delim+1);
+    else {
+      	delim = dataset.rfind("/");
+	if ( delim != string::npos ) 
+	  FileName = dataset.substr(delim+1,dataset.length()-delim+1);
+	else
+	  FileName = dataset;
+    }
+
+    delim = FileName.find("_");
+    if ( delim != string::npos ) {
+      BaseName = FileName.substr(0,delim+1);
+    }
+    else {
+      string msg = "Could not find input format for: ";
+      msg += dataset;
+      throw InternalErr(msg);
+    }
+
+    string DatePart = FileName.substr(delim+1, FileName.length()-delim+1);
+    
+    if ( (DatePart.find("_") != string::npos) || (DatePart.length() < 10) )
+        FormatFile = FormatPath + BaseName + "averaged.fmt";
+    else
+        FormatFile = FormatPath + BaseName + "daily.fmt";
+
+    return string(FormatFile);
+}
+
+/** Find the RSS (Remote Sensing Systems) format file using their naming
+    convention.
+
+    File naming convention: <data source> + '_' + <date_string> + <version> +
+    (optional)< _d3d > When <date_string> includes YYYYMMDDVV ('DD') the file
+    contains 'daily' data. When <date_string> only includes YYYYMMVV ( no
+    'DD'), or includes ('DD') and optional '_d3d' then the file contains
+    averaged data.
+
+    Different format files are required for 'daily' and 'averaged' data.
+
+    @return A const string object which contains the format file name. */
+const string
+find_ancillary_rss_das(const string & dataset, const string & delimiter,
+		       const string & extension)
+{
+    string FormatFile;
+    //string FormatPath = getenv("FREEFORM_HANDLER_FORMATS");
+    string FormatPath = FREEFORM_HANDLER_FORMATS;
+    string BaseName;
+    string FileName;
+
+    size_t delim = dataset.rfind("#");
+    if ( delim != string::npos ) 
+      FileName = dataset.substr(delim+1,dataset.length()-delim+1);
+    else {
+      	delim = dataset.rfind("/");
+	if ( delim != string::npos ) 
+	  FileName = dataset.substr(delim+1,dataset.length()-delim+1);
+	else
+	  FileName = dataset;
+    }
+
+    delim = FileName.find("_");
+    if ( delim != string::npos ) {
+        BaseName = FileName.substr(0,delim+1);
+    }
+    else {
+        string msg = "Could not find input format for: ";
+        msg += dataset;
+        throw InternalErr(msg);
+    }
+
+    string DatePart = FileName.substr(delim+1, FileName.length()-delim+1);
+    
+    if ( (DatePart.find("_") != string::npos) || (DatePart.length() < 10) )
+        FormatFile = FormatPath + BaseName + "averaged.das";
+    else
+        FormatFile = FormatPath + BaseName + "daily.das";
+
+    return string(FormatFile);
+}
+
+// *** Cruft from a --reintegrate merge from 3.7.9? 
+#if 0
 /** Find the format file using a delimiter character.
     Given a special sequence of one or more characters, use that to determine
     the format file name. Assume that the format file ends with EXTENSION.
@@ -316,8 +425,8 @@ bool file_exist(const char *filename)
 
     @return A const string object which contains the format file name. */
 const string
-find_ancillary_file(const string & dataset, const string & delimiter,
-                    const string & extension)
+find_ancillary_formats(const string & dataset, const string & delimiter,
+		       const string & extension)
 {
     size_t delim = dataset.find(delimiter);
     string basename = dataset.substr(0, delim);
@@ -382,6 +491,7 @@ find_ancillary_file(const string & dataset, const string & delimiter,
             				  + string(FileName));
         }
 }
+#endif
 
 // These functions are used by the Date/Time Factory classes but they might
 // be generally useful in writing server-side functions. 1/21/2002 jhrg
